@@ -1,7 +1,16 @@
+import os
 import math
 
+
+# Define the path to our custom .ttf font
+free_type_compatible_font = os.path.abspath(
+    os.path.join(
+        os.path.dirname(__file__), 'fonts/xd.ttf'
+    )
+)
+print(free_type_compatible_font)
 from PIL import ImageDraw, ImageFont 
-font = ImageFont.truetype(font="FreeMono.ttf", size=100)
+font = ImageFont.truetype(font=free_type_compatible_font, size=100)
 
 
 class Layer:
